@@ -770,7 +770,11 @@ class NumerousClient:
         )
 
     def get_download_files(
-        self, files, local_path="./tmp", scenario=None, project_id=None
+        self,
+        files: list[str],
+        local_path: str = "./tmp",
+        scenario: str | None = None,
+        project_id: str | None = None,
     ):
         os.makedirs(local_path, exist_ok=True)
         if scenario is None:
@@ -778,16 +782,16 @@ class NumerousClient:
         if project_id is None:
             project_id = self._project
 
-        files = self._base_client.GetSignedURLs(
+        signed_urls = self._base_client.GetSignedURLs(
             spm_pb2.FilePaths(
-                files=[spm_pb2.FileSignedUrl(path=scenario + "/" + f) for f in files],
+                file_paths=[spm_pb2.FilePath(path=f"{scenario}/{fn}") for fn in files],
                 scenario=scenario,
                 project_id=project_id,
             )
         )
 
         files_out = {}
-        for f in files.files:
+        for f in signed_urls.files:
             r = requests.get(f.url, allow_redirects=True)
             local_file_path = local_path + "/" + f.name
             open(local_file_path, "wb").write(r.content)
@@ -1308,8 +1312,9 @@ class NumerousClient:
             yield data[i : i + size]
 
         size = length // parts
-        for i in range(rest_start, length, size):
-            yield data[i : i + size]
+        if size:
+            for i in range(rest_start, length, size):
+                yield data[i : i + size]
 
     def _rows_to_blocks(self, rows) -> list[spm_pb2.DataBlock]:
         if len(rows) == 0:
@@ -1338,11 +1343,9 @@ class NumerousClient:
     ):
         if must_flush is None:
 
-            def must_flush_(_n, _m):
+            def must_flush(_n, _m):
                 return True
 
-            must_flush = must_flush_
-
         if scenario is None:
             scenario = self._scenario
 
