@@ -14,7 +14,7 @@ class AccessTokenAuthMetadataPlugin(grpc.AuthMetadataPlugin):
         context: grpc.AuthMetadataContext,  # noqa: F841
         callback: grpc.AuthMetadataPluginCallback,
     ):
-        callback([("authorization", self._access_token)], None)
+        callback([("token", self._access_token)], None)
 
     def __eq__(self, other):
         if isinstance(other, AccessTokenAuthMetadataPlugin):
